@@ -202,7 +202,7 @@ class HarConverter:
                 entry["data"] = post_data.get("params")
             elif post_data.get("text"):
                 # according to spec, 'text' should be mutually exclusive to 'params'
-                # but Chrome produces both
+                # but Chrome produces both or sometimes text only:
                 entry["data"] = post_data.get("text")
 
         if resp.get("comment"):
@@ -369,7 +369,7 @@ class HarConverter:
             #       if the list does contain duplicate names, instead of
             #       dicarding.
             name, value = p["name"], p["value"]
-            # lines.append('    - ["{}", {}]\n'.format(name, json.dumps(value)))
+            # lines.append("    - ['{}', {}]\n".format(name, json.dumps(value)))
 
             if name in used:
                 logger.error(
@@ -415,12 +415,12 @@ class HarConverter:
             lines.append("  thread_count: {}\n".format(opts["collate_thread_count"]))
             lines.append("  url_list:\n")
             for url in url_list:
-                lines.append('    - "{}"\n'.format(url))
+                lines.append("    - '{}'\n".format(url))
         else:
             if entry.get("query"):
                 expand_url_params = True
                 url = base_url(url)
-            lines.append('  url: "{}"\n'.format(url))
+            lines.append("  url: '{}'\n".format(url))
 
         if activity == "HTTPRequest":
             lines.append("  method: {}\n".format(entry["method"]))
@@ -442,8 +442,8 @@ class HarConverter:
                 self._write_args(lines, "data", data)
             else:
                 assert type(data) is str
-                logger.warning("Did not expect text: {}".format(data))
-                lines.append('  data: "{}"\n'.format(json.dumps(data)))
+                logger.warning("Expected list, but got text: {!r}".format(data))
+                lines.append("  data: {}\n".format(json.dumps(data)))
 
         lines.append("\n")
         fp.writelines(lines)
