@@ -6,30 +6,24 @@ Stress-test your web app.
 Licensed under the MIT license: https://www.opensource.org/licenses/mit-license.php
 
 Usage examples:
-  $ stressor --help
-  $ stressor run .
+    $ stressor --help
+    $ stressor run .
 """
 import argparse
 import os
-import platform
 import sys
 
 import yaml
 
+from snazzy import enable_colors
 from stressor import __version__
 from stressor.cli_common import common_parser, verbose_parser
 from stressor.convert.har_converter import HarConverter
-from stressor.log import log
 from stressor.run_manager import RunManager
-from stressor.util import init_logging, logger
+from stressor.util import init_logging, logger, version_info
 
 
 def handle_run_command(parser, args):
-    # try:
-    #     config = read_config(args.scenario, verbose=args.verbose)
-    # except ConfigurationError as e:
-    #     parser.error("{}".format(e))
-
     options = {
         "monitor": args.monitor,
         "log_summary": True,
@@ -39,10 +33,15 @@ def handle_run_command(parser, args):
         "dry_run": args.dry_run,
     }
 
+    scenario_fspec = args.scenario
+    if os.path.isdir(scenario_fspec):
+        scenario_fspec = os.path.join(scenario_fspec, "scenario.yaml")
+        logger.info("Looking for {}".format(scenario_fspec))
+
     rm = RunManager()
-    rm.load_config(args.scenario)
+    rm.load_config(scenario_fspec)
     if args.single:
-        rm.run_config["force_single"] = True
+        rm.config_manager.config["force_single"] = True
 
     res = rm.run(options, extra_context)
 
@@ -96,11 +95,6 @@ def run():
         action="store_true",
         help="display version info and exit (combine with -v for more information)",
     )
-    # parser.add_argument(
-    #     "--no-color",
-    #     action="store_true",
-    #     help="prevent use of ansi terminal color codes",
-    # )
     subparsers = parser.add_subparsers(help="sub-command help")
 
     # --- Create the parser for the "run" command ------------------------------
@@ -115,7 +109,7 @@ def run():
         "scenario",
         metavar="SCENARIO",
         default="./scenario.yaml",
-        help="path to configuration file (default: %(default)s)",
+        help="path to configuration file or folder (default: %(default)s)",
     )
     sp.add_argument(
         "-o",
@@ -149,9 +143,6 @@ def run():
         # default="./scenario.yaml",
         help="target folder (created if not existing)",
     )
-    # sp.add_argument(
-    #     "--target", required=True, help="target folder",
-    # )
     sp.add_argument(
         "--import",
         dest="har_file",
@@ -210,20 +201,16 @@ def run():
     # print("verbose", args.verbose)
     init_logging(args.verbose, args.log_file)
 
-    if not args.no_color and sys.stdout.isatty():
-        log.enable_color(True)
+    if not args.no_color:
+        enable_colors(True, force=False)
 
     if getattr(args, "version", None):
         if args.verbose >= 4:
-            PYTHON_VERSION = "{}.{}.{}".format(
-                sys.version_info[0], sys.version_info[1], sys.version_info[2]
-            )
-            version_info = "stressor/{} Python/{} {}".format(
-                __version__, PYTHON_VERSION, platform.platform()
-            )
+            info = version_info
+            info += "\nPython from: {}".format(sys.executable)
         else:
-            version_info = __version__
-        print(version_info)
+            info = __version__
+        print(info)
         sys.exit(0)
 
     if not callable(getattr(args, "command", None)):
