@@ -5,23 +5,49 @@
 """
 import logging
 import os
+import platform
 import random
 import re
 import sys
 import types
 import warnings
 from datetime import datetime
+from urllib.parse import urljoin, urlparse
 
 from dateutil.parser import isoparse
-from urllib.parse import urlparse, urljoin
 
+from stressor import __version__
 
 logger = logging.getLogger("stressor")
 
+# Use logger.important("message even in -q mode")
+LOGLEVEL_IMPORTANT = logging.WARNING + 1
+logging.addLevelName(LOGLEVEL_IMPORTANT, "NOTE")
+
+
+def log_important(self, message, *args, **kws):
+    if self.isEnabledFor(LOGLEVEL_IMPORTANT):
+        # Yes, logger takes its '*args' as 'args'.
+        self._log(LOGLEVEL_IMPORTANT, message, args, **kws)
+
+
+logging.Logger.important = log_important
+
+
 #: Check if a a string may be used as YAML dictionary key without using quotes.
 #: NOTE: YAML evaluates `0_` as "0" and `0_1_` as "1", so we don't accept leading numbers
 RE_YAML_KEYWORD = re.compile(r"^[a-zA-Z_]+\w*$")
 
+PYTHON_VERSION = "{}.{}.{}".format(
+    sys.version_info[0], sys.version_info[1], sys.version_info[2]
+)
+version_info = "stressor/{} Python/{}({} bit) {}".format(
+    __version__,
+    PYTHON_VERSION,
+    "64" if sys.maxsize > 2 ** 32 else "32",
+    platform.platform(),
+)
+
 
 class StressorError(RuntimeError):
     """Base class for all exception that we deliberatly throw."""
@@ -157,6 +183,7 @@ def init_logging(verbose=3, path=None):
         logger.addHandler(hdlr)
         # logger.setLevel(logging.DEBUG)
         logger.info("Start log ({})".format(datetime.now()))
+        logger.info(version_info)
         logger.info("Running {}".format(" ".join(sys.argv)))
 
         # redirect `logger` to our special log file as well:
